<?php

/**
 * Common theme elements definition.
 *
 * @see system_forge_element()
 */
function _system_forge_element_theme() {
  $element['theme_html_tag'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'HTML tag',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a generic HTML tag with attributes.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_html_tag/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_html/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21html.html.twig/8

  $element['theme_box'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme box',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '$title, $content, $region = \'main\'',
    ),
    'info' => array(
      'description' => 'Return a themed box.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_box/6',
      ),
    ),
  );

  $element['theme_help'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Themed help message',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'info' => array(
      'description' => 'Return a themed help message.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_help/6',
      ),
    ),
  );

  $element['theme_submenu'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Themed submenu',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '$links',
    ),
    'info' => array(
      'description' => 'Return a themed submenu, typically displayed under the tabs.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_submenu/6',
      ),
    ),
  );

  $element['theme_blocks'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme blocks of an region',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '$region',
    ),
    'info' => array(
      'description' => 'Return a set of blocks available for the current user.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_blocks/6',
      ),
    ),
  );

  $element['theme_status_messages'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Status messages',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$display = NULL',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for status and/or error messages, grouped by type.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_status_messages/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_status_messages/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_status_messages/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21status-messages.html.twig/8

  $element['theme_breadcrumb'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Breadcrumb trail',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$breadcrumb',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a breadcrumb trail.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_breadcrumb/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_breadcrumb/7',
      ),
    ),
  );

  $element['theme_links'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Set of links',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$links, $attributes = array(\'class\' => \'links\')',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a set of links.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_links/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_links/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_links/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21links.html.twig/8

  $element['theme_link'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Themed link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a link.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_link/7',
      ),
    ),
  );

  $element['theme_item_list'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'List of items',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'description' => 'Returns HTML for a list or nested list of items.',
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$items = array(), $title = NULL, $type = \'ul\', $attributes = NULL',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => '',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => '',
        Forge::CORE_SUPPORT_7x => '',
        Forge::CORE_SUPPORT_8x => '',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_item_list/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21item-list.html.twig/8

  $element['theme_table'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Themed table',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$header, $rows, $attributes = array(), $caption = NULL',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a table.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_table/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_table/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/theme_table/8',
      ),
    ),
  );

  $element['theme_tablesort_indicator'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Tablesort icon',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$style',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a sort icon.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_tablesort_indicator/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_tablesort_indicator/7',
      ),
    ),
  );

  $element['theme_table_select_header_cell'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Header cell for tables',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'info' => array(
      'description' => 'Returns a header cell for tables that have a select all functionality.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_table_select_header_cell/6',
      ),
    ),
  );

  $element['theme_username'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme username',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$object',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a username, potentially linked to the user\'s page.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_username/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_username/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21modules%21user%21user.module/function/theme_username/8',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21modules%21user%21user.module/function/template_preprocess_username/8

  $element['theme_image'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme image',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$path, $alt = \'\', $title = \'\', $attributes = NULL, $getsize = TRUE',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for an image.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_image/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_image/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_image/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21image.html.twig/8

  $element['theme_mark'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Themed marker for new or updated content',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$type = MARK_NEW',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a marker for new or updated content.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_mark/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_mark/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/theme_mark/8',
      ),
    ),
  );

  $element['theme_more_link'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme more link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$url, $title',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a "more" link, like those used in blocks.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_more_link/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_more_link/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/theme_more_link/8',
      ),
    ),
  );

  $element['theme_more_help_link'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'More help link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$url',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a "more help" link.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_more_help_link/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_more_help_link/7',
      ),
    ),
  );

  $element['theme_feed_icon'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Feed icon',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$url, $title',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a feed icon.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_feed_icon/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_feed_icon/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_feed_icon/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21feed-icon.html.twig/8

  $element['theme_xml_icon'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'XML icon',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '$url',
    ),
    'info' => array(
      'description' => 'Return code that emits an XML icon.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_xml_icon/6',
      ),
    ),
  );

  $element['theme_progress_bar'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Themed progress bar',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$percent, $message',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Return a themed progress bar.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_progress_bar/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_progress_bar/7',
      ),
    ),
  );

  $element['theme_indentation'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme indentation div',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$size = 1',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for an indentation div; used for drag and drop tables.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_indentation/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_indentation/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/theme_indentation/8',
      ),
    ),
  );

  $element['theme_placeholder'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme placeholder',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '$text',
    ),
    'info' => array(
      'description' => 'Formats text for emphasized display in a placeholder inside a sentence. Used automatically by t().',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_placeholder/6',
      ),
    ),
  );

  $element['theme_closure'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme page end elements',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '$main = 0',
    ),
    'info' => array(
      'description' => 'Execute hook_footer() which is run at the end of the page right before the close of the body tag.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/theme_closure/6',
      ),
    ),
  );

  $element['template_preprocess'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Default set of helper variables',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '&$variables, $hook',
        Forge::CORE_SUPPORT_7x => '&$variables, $hook',
        Forge::CORE_SUPPORT_8x => '&$variables, $hook, $info',
      ),
    ),
    'info' => array(
      'description' => 'Adds a default set of helper variables for variable processors and templates.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess/8',
      ),
    ),
  );

  $element['template_preprocess_html'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Preprocess variables for html.tpl.php',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Preprocess variables for html.tpl.php',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess_html/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_html/8',
      ),
    ),
  );

  $element['template_preprocess_page'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Preprocess variables for page.tpl.php',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme',
    'options' => array(
      'description' => 'Preprocess variables for page.tpl.php',
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => '',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess_page/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess_page/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_page/8',
      ),
    ),
  );

  $element['template_preprocess_region'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Preprocess variables for region.tpl.php',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Preprocess variables for region.tpl.php',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess_region/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_region/8',
      ),
    ),
  );

  $element['template_preprocess_username'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Preprocesses variables for theme_username().',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Preprocesses variables for theme_username().',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess_username/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21modules%21user%21user.module/function/template_preprocess_username/8',
      ),
    ),
  );

  $element['template_process'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Adds helper variables after preprocessing',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables, $hook',
    ),
    'info' => array(
      'description' => 'Adds helper variables derived from variables defined during preprocessing.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_process/7',
      ),
    ),
  );

  $element['template_process_html'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Process variables for html.tpl.php',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Process variables for html.tpl.php',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_process_html/7',
      ),
    ),
  );

  $element['template_process_page'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Process variables for page.tpl.php',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Process variables for page.tpl.php',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_process_page/7',
      ),
    ),
  );

  $element['template_process_username'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Processes variables for theme_username().',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Processes variables for theme_username().',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_process_username/7',
      ),
    ),
  );

  return $element;
}

/**
 * Theme elements definition declared in system module.
 *
 * @see system_forge_element()
 */
function _system_forge_element_theme_system() {
  $element['theme_confirm_form'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme confirmation form',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme_system',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a confirmation form.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/modules%21system%21system.module/function/theme_confirm_form/7',
      ),
    ),
  );

  $element['theme_exposed_filters'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme exposed filter form',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme_system',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for an exposed filter form.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/modules%21system%21system.module/function/theme_exposed_filters/7',
      ),
    ),
  );

  return $element;
}

/**
 * Form theme elements definition.
 *
 * @see system_forge_element()
 */
function _system_forge_element_theme_form() {
  $element['theme_form'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme form',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a form.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_form/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_form/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/template_preprocess_form/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21form.html.twig/8

  $element['theme_container'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Child elements wrapper',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML to wrap child elements in a container.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_container/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_container/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21container.html.twig/8

  $element['theme_fieldset'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme fieldset',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a fieldset form element and its children.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_fieldset/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_fieldset/7',
      ),
    ),
  );

  $element['theme_vertical_tabs'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme fieldsets as vertical tabs',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for an element\'s children fieldsets as vertical tabs.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_vertical_tabs/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/template_preprocess_vertical_tabs/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21vertical-tabs.html.twig/8

  $element['theme_form_element'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme form element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element, $value',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_form_element/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_form_element/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/template_preprocess_form_element/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21form-element.html.twig/8

  $element['theme_item'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Format a form item.',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$element',
    ),
    'info' => array(
      'description' => 'Format a form item.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_item/6',
      ),
    ),
  );

  $element['theme_textfield'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme textfield element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a textfield form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_textfield/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_textfield/7',
      ),
    ),
  );

  $element['theme_textarea'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme textarea element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a textarea form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_textarea/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_textarea/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/template_preprocess_textarea/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21textarea.html.twig/8

  $element['theme_password'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme password element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a password form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_password/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_password/7',
      ),
    ),
  );

  $element['theme_password_confirm'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme password_confirm item',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$element',
    ),
    'info' => array(
      'description' => 'Format a password_confirm item.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_password_confirm/6',
      ),
    ),
  );

  $element['theme_select'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme select element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a select form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_select/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_select/7',
      ),
    ),
  );

  $element['theme_radio'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'The radio button',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a radio button form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_radio/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_radio/7',
      ),
    ),
  );

  $element['theme_radios'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme set of radio button',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a set of radio button form elements.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_radios/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_radios/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/template_preprocess_radios/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21radios.html.twig/8

  $element['theme_checkbox'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme checkbox element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a checkbox form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_checkbox/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_checkbox/7',
      ),
    ),
  );

  $element['theme_checkboxes'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme set of checkbox',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a set of checkbox form elements.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_checkboxes/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_checkboxes/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/template_preprocess_checkboxes/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21checkboxes.html.twig/8

  $element['theme_date'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme date selection element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a date selection form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_date/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_date/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/theme_date/8',
      ),
    ),
  );

  $element['theme_file'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme file upload element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a file upload form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_file/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_file/7',
      ),
    ),
  );

  $element['theme_token'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme form token',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$element',
    ),
    'info' => array(
      'description' => 'Format a form token.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_token/6',
      ),
    ),
  );

  $element['theme_markup'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme markup element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$element',
    ),
    'info' => array(
      'description' => '',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_markup/6',
      ),
    ),
  );

  $element['theme_hidden'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme hidden element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$element',
    ),
    'info' => array(
      'description' => 'Format a hidden form field.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_hidden/6',
      ),
    ),
  );

  $element['theme_submit'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme submit button element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a submit button form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_submit/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_submit/7',
      ),
    ),
  );

  $element['theme_button'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme button element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a button form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_button/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_button/7',
      ),
    ),
  );

  $element['theme_image_button'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme image button element',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_form',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$element',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for an image button form element.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_image_button/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_image_button/7',
      ),
    ),
  );

  $element['theme_tableselect'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme table with radio buttons or checkboxes',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a table with radio buttons or checkboxes.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_tableselect/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/theme_tableselect/8',
      ),
    ),
  );

  $element['theme_form_required_marker'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme marker for required elements',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a marker for required form elements.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_form_required_marker/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/theme_form_required_marker/8',
      ),
    ),
  );

  $element['theme_form_element_label'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme label and required marker',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme_form',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a form element label and required marker.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21form.inc/function/theme_form_element_label/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21form.inc/function/theme_form_element_label/8',
      ),
    ),
  );

  return $element;
}

/**
 * Pager theme elements definition.
 *
 * @see system_forge_element()
 */
function _system_forge_element_theme_pager() {
  $element['theme_pager'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme query pager',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_pager',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$tags = array(), $limit = 10, $element = 0, $parameters = array(), $quantity = 9',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a query pager.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21pager.inc/function/template_preprocess_pager/8
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21pager.html.twig/8

  $element['theme_pager_first'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme "first page" link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_pager',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$text, $limit, $element = 0, $parameters = array()',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for the "first page" link in a query pager.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_first/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_first/7',
      ),
    ),
  );

  $element['theme_pager_previous'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme "previous page" link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_pager',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$text, $limit, $element = 0, $interval = 1, $parameters = array()',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for the "previous page" link in a query pager.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_previous/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_previous/7',
      ),
    ),
  );

  $element['theme_pager_link'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Thme pager link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_pager',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$text, $page_new, $element, $parameters = array(), $attributes = array()',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a link to a specific query result page.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_link/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_link/7',
      ),
    ),
  );

  $element['theme_pager_next'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme "next page" link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_pager',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$text, $limit, $element = 0, $interval = 1, $parameters = array()',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for the "next page" link in a query pager.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_next/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_next/7',
      ),
    ),
  );

  $element['theme_pager_last'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme "last page" link',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_pager',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$text, $limit, $element = 0, $parameters = array()',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for the "last page" link in query pager.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_last/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21pager.inc/function/theme_pager_last/7',
      ),
    ),
  );


  return $element;
}

/**
 * Maintenance theme elements definition.
 *
 * @see system_forge_element()
 */
function _system_forge_element_theme_maintenance() {
  $element['theme_install_page'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme installation page',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$content',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for the installation page.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_install_page/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_install_page/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_install_page/8
  // D8: https://api.drupal.org/api/drupal/8/search/install-page.html.twig

  $element['theme_update_page'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme update page',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$content, $show_messages = TRUE',
        Forge::CORE_SUPPORT_7x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for the update page.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_update_page/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_update_page/7',
      ),
    ),
  );

  $element['theme_task_list'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme list of maintenance tasks',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => array(
        Forge::CORE_SUPPORT_6x => '$items, $active = NULL',
        Forge::CORE_SUPPORT_7x => '$variables',
        Forge::CORE_SUPPORT_8x => '$variables',
      ),
    ),
    'info' => array(
      'description' => 'Returns HTML for a list of maintenance tasks to perform.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_task_list/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_task_list/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.maintenance.inc/function/theme_task_list/8',
      ),
    ),
  );

  $element['theme_authorize_report'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme results report',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a results report of an operation run by authorize.php.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_authorize_report/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.maintenance.inc/function/theme_authorize_report/8',
      ),
    ),
  );

  $element['theme_authorize_message'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme single log message',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_MORE_THAN_6x,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => '$variables',
    ),
    'info' => array(
      'description' => 'Returns HTML for a single log message from the authorize.php batch operation.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/theme_authorize_message/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.maintenance.inc/function/theme_authorize_message/8',
      ),
    ),
  );

  $element['template_preprocess_maintenance_page'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Process variables for maintenance-page.tpl.php.',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_ALL,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Process variables for maintenance-page.tpl.php.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/includes%21theme.maintenance.inc/function/template_preprocess_maintenance_page/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_preprocess_maintenance_page/7',
        Forge::CORE_SUPPORT_8x => 'https://api.drupal.org/api/drupal/core%21includes%21theme.inc/function/template_preprocess_maintenance_page/8',
      ),
    ),
  );

  $element['template_process_maintenance_page'] = array(
    'class' => 'Forge_Element_Theme',
    'name' => 'Theme process function for theme_maintenance_field().',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme_maintenance',
    'options' => array(
      'args' => '&$variables',
    ),
    'info' => array(
      'description' => 'Theme process function for theme_maintenance_field().',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/includes%21theme.inc/function/template_process_maintenance_page/7',
      ),
    ),
  );

  return $element;
}

/**
 * Common template elements definition.
 *
 * @see system_forge_element()
 */
function _system_forge_element_template() {
  $element['html.tpl.php'] = array(
    'class' => 'Forge_Element_Template',
    'name' => 'Basic html structure of a page',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => 'modules/system/html.tpl.php',
    ),
    'info' => array(
      'description' => 'Default theme implementation to display the basic html structure of a single Drupal page.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/modules%21system%21html.tpl.php/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21html.html.twig/8

  $element['page.tpl.php'] = array(
    'class' => 'Forge_Element_Template',
    'name' => 'Theme implementation to display a page',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => 'modules/system/page.tpl.php',
    ),
    'info' => array(
      'description' => 'Default theme implementation to display a single Drupal page.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/modules%21system%21page.tpl.php/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/modules%21system%21page.tpl.php/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21page.html.twig/8

  $element['maintenance-page.tpl.php'] = array(
    'class' => 'Forge_Element_Template',
    'name' => 'Theme implementation to display a offline page',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_BOTH_6x_7x,
    'group' => 'theme',
    'options' => array(
      'args' => 'modules/system/maintenance-page.tpl.php',
    ),
    'info' => array(
      'description' => 'Default theme implementation to display a single Drupal page while offline.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_6x => 'https://api.drupal.org/api/drupal/modules%21system%21maintenance-page.tpl.php/6',
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/modules%21system%21maintenance-page.tpl.php/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21maintenance-page.html.twig/8

  $element['region.tpl.php'] = array(
    'class' => 'Forge_Element_Template',
    'name' => 'Theme implementation to display a region',
    'defaultValue' => FALSE,
    'projectType' => Forge::PROJECT_TYPE_THEME,
    'coreSupport' => Forge::CORE_SUPPORT_7x,
    'group' => 'theme',
    'options' => array(
      'args' => 'modules/system/region.tpl.php',
    ),
    'info' => array(
      'description' => 'Default theme implementation to display a region.',
      'apiUrl' => array(
        Forge::CORE_SUPPORT_7x => 'https://api.drupal.org/api/drupal/modules%21system%21region.tpl.php/7',
      ),
    ),
  );
  // D8: https://api.drupal.org/api/drupal/core%21modules%21system%21templates%21region.html.twig/8

  return $element;
}
